##  Fact Sheet Attributes
The table below lists the fact sheet attributes provided by the reference catalog. These attributes might not always be available for all catalog items.
  * Base attributes are available to all customers using SAP LeanIX Application Portfolio Management, our base product.
  * Additional attributes related to technology risk and compliance are available only to customers using SAP LeanIX Technology Risk and Compliance. To learn more about this product, see [SAP LeanIX Technology Risk and Compliance](https://help.sap.com/docs/leanix/ea/sap-leanix-technology-risk-and-compliance?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of SAP LeanIX Technology Risk and Compliance, with links to detailed guides for managing obsolescence risk, optimizing technology usage, and enforcing tech standards across your IT landscape.").


Fact Sheet Type | Base Attributes | Additional Attributes Available with the SAP LeanIX Technology Risk and Compliance Product
---|---|---
Business capability |
  * Name and Description
  * Relevance for Industries
  * Enterprise Domain
  * SAP Reference ID
  * SAP application recommendations
  * Relations to other catalog items

|
Application |  Attributes for applications:
  * Name and Description
  * Product Category
  * Hosting options
  * Single sign-on (SSO) information
  * Relations to other catalog items
  * As of Date
  * External ID

Attributes for AI agents:
  * Name and Description
  * External ID

| Security and policy links
IT component |
  * Name and Description
  * IT Component Subtype
  * Release
  * Component Website
  * Relations to other catalog items
  * As of Date
  * External ID

| Lifecycle information (phases, URLs, support policies, and more)
Tech category |
  * Name and Description

|
Provider (if linked to applications or IT components) |
  * Name

|


